pub struct HsDescSigningKey(PublicKey);Expand description
A key used to sign onion service descriptors. (KP_desc_sign)
It is authenticated with a HsBlindIdKey to prove that it belongs to
the right onion service, and is used in turn to sign the descriptor that
tells clients what they need to know about contacting an onion service.
Onion services create a new DescSigningKey every time the
HsBlindIdKey rotates, to prevent descriptors made in one time period
from being linkable to those made in another.
Note: we use a separate signing key here, rather than using the
HsBlindIdKey directly, so that the HsBlindIdKeypair
can be kept offline.
Tuple Fields
0: PublicKeyMethods from Deref<Target = PublicKey>