pub struct HsIntroPtSessionIdKey(PublicKey);Expand description
A key used to identify and authenticate an onion service at a single
introduction point. (KP_hs_ipt_sid)
This key is included in the onion service’s descriptor; a different one is used at each introduction point. Introduction points don’t know the relation of this key to the onion service: they only recognize the same key when they see it again.
Tuple Fields
0: PublicKeyMethods from Deref<Target = PublicKey>