pub struct HsSvcNtorKey(PublicKey);Expand description
A key used in the HsNtor handshake between the client and the onion service.
(KP_hss_ntor)
The onion service chooses a different one of these to use with each introduction point, though it does not need to tell the introduction points about these keys.
Tuple Fields
0: PublicKeyTrait Implementations
Sourceimpl AsRef<PublicKey> for HsSvcNtorKey
impl AsRef<PublicKey> for HsSvcNtorKey
Sourceimpl Clone for HsSvcNtorKey
impl Clone for HsSvcNtorKey
Sourcefn clone(&self) -> HsSvcNtorKey
fn clone(&self) -> HsSvcNtorKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstantTimeEq for HsSvcNtorKeywhere
PublicKey: ConstantTimeEq,
impl ConstantTimeEq for HsSvcNtorKeywhere
PublicKey: ConstantTimeEq,
Sourceimpl Debug for HsSvcNtorKey
impl Debug for HsSvcNtorKey
Sourceimpl Deref for HsSvcNtorKey
impl Deref for HsSvcNtorKey
Sourceimpl From<HsSvcNtorKey> for PublicKey
impl From<HsSvcNtorKey> for PublicKey
Sourcefn from(value: HsSvcNtorKey) -> Self
fn from(value: HsSvcNtorKey) -> Self
Converts to this type from the input type.
Sourceimpl From<PublicKey> for HsSvcNtorKey
impl From<PublicKey> for HsSvcNtorKey
Sourceimpl PartialEq for HsSvcNtorKeywhere
HsSvcNtorKey: ConstantTimeEq,
impl PartialEq for HsSvcNtorKeywhere
HsSvcNtorKey: ConstantTimeEq,