pub(super) struct Challenge([u8; 100]);Expand description
A fully assembled challenge string, with some access to inner fields
This is the combined input to Equi-X. Defined by Proposal 327
as (P || ID || C || N || INT_32(E))
Tuple Fields
0: [u8; 100]Implementations
Sourceimpl Challenge
impl Challenge
Sourcepub(super) fn increment_nonce(&mut self)
pub(super) fn increment_nonce(&mut self)
Increment the Nonce value inside this challenge.
Note that this will take a different amount of time depending on the number of bytes affected. There’s no timing side channel here: The timing variation here is swamped by variation in the solver itself, and the nonce is not a secret value.
Sourcepub(super) fn check_effort(
&self,
proof: &SolutionByteArray,
) -> Result<(), SolutionErrorV1>
pub(super) fn check_effort( &self, proof: &SolutionByteArray, ) -> Result<(), SolutionErrorV1>
Verify that a solution proof passes the effort test.
This computes a Blake2b hash of the challenge and the serialized Equi-X solution, and tests the result against the effort encoded in the challenge string.
Used by both the crate::pow::v1::Solver and the crate::pow::v1::Verifier.