#[non_exhaustive]pub enum RuntimeOption {
InterpretOnly,
CompileOnly,
TryCompile,
}Expand description
Option for selecting a HashX runtime
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InterpretOnly
Choose the interpreted runtime, without trying the compiler at all.
CompileOnly
Choose the compiled runtime only, and fail if it experiences any errors.
TryCompile
Always try the compiler first but fall back to the interpreter on error. (This is the default)