pub struct Effort(u32);Expand description
Effort setting, a u32 value with linear scale
The numerical value is roughly the expected number of times we will need to invoke the underlying solver (Equi-X) for the v1 proof-of-work protocol to find a solution.
Tuple Fields
0: u32Implementations
Sourceimpl Effort
impl Effort
Sourcepub const fn new(value: u32) -> Self
pub const fn new(value: u32) -> Self
Const constructor for Effort from any u32
Effort can also be constructed using into() conversions,
but those are not available in const expressions.
Sourcepub const fn zero() -> Self
pub const fn zero() -> Self
Const constructor for zero effort
Zero effort is used in suggested effort to mean the puzzle is available but shouldn’t be used on a first connection attempt.
If zero is actually used for solve and verify, it will have equivalent performance to an effort of 1.
Sourcepub const fn saturating_mul_u32(&self, rhs: u32) -> Self
pub const fn saturating_mul_u32(&self, rhs: u32) -> Self
Multiply this effort by an integer of the same size, saturating on overflow
Sourcepub fn saturating_mul_f32(&self, rhs: f32) -> Self
pub fn saturating_mul_f32(&self, rhs: f32) -> Self
Multiply this effort by a float, with saturating cast back to Effort