pub struct Instance {
service: HsBlindId,
seed: Seed,
}Expand description
One instance of this proof-of-work puzzle
Identified uniquely by the combination of onion service blinded Id key plus a rotating seed chosen by the service.
Fields
service: HsBlindIdBlinded public Id key, binding this puzzle to a specific onion service
seed: SeedSeed value distributed in the HsDir by that service
Implementations