pub struct Solution {
nonce: Nonce,
effort: Effort,
seed_head: SeedHead,
proof: Solution,
}Expand description
Fields
nonce: NonceArbitrary value chosen by the solver to reach a valid solution
Services are responsible for remembering used values to prevent replay.
effort: EffortThe effort chosen by the client
This is validated against the actual effort spent by the client using a combination of two checks:
-
We can ensure the effort value here was chosen prior to successfully solving the Equi-X puzzle just by verifying the Equi-X proof. Effort values are part of the
crate::pow::v1::challenge::Challengestring the puzzle is constructed around. -
We can ensure, on average, that the proper proportion of Equi-X solutions have been discarded. The proof and challenge are hashed, and the resulting digest is effectively a random variable that must fit within a range inversely proportional to the effort. This test happens in
crate::pow::v1::challenge::Challenge::check_effort.
seed_head: SeedHeadPrefix of the Seed used in this puzzle Instance
A service will normally have two active Seed values at once.
This prefix is sufficient to distinguish between them. (Services
skip seeds which would have the same prefix as the last seed.)
proof: SolutionEqui-X solution which claims to prove the above effort choice
Implementations
Sourceimpl Solution
impl Solution
Sourcepub fn new(
nonce: Nonce,
effort: Effort,
seed_head: SeedHead,
proof: Solution,
) -> Self
pub fn new( nonce: Nonce, effort: Effort, seed_head: SeedHead, proof: Solution, ) -> Self
Construct a new Solution around a well-formed equix::Solution proof.
Sourcepub fn try_from_bytes(
nonce: Nonce,
effort: Effort,
seed_head: SeedHead,
bytes: &SolutionByteArray,
) -> Result<Self, SolutionErrorV1>
pub fn try_from_bytes( nonce: Nonce, effort: Effort, seed_head: SeedHead, bytes: &SolutionByteArray, ) -> Result<Self, SolutionErrorV1>
Try to build a Solution from an unvalidated equix::SolutionByteArray.
This will either return a Solution or a SolutionErrorV1::Order.
Sourcepub fn effort(&self) -> Effort
pub fn effort(&self) -> Effort
Get the client-chosen and provable Effort value used in this solution
Sourcepub fn seed_head(&self) -> SeedHead
pub fn seed_head(&self) -> SeedHead
Get the SeedHead value identifying the puzzle this solution is for
Sourcepub fn proof(&self) -> &Solution
pub fn proof(&self) -> &Solution
Reference the equix::Solution backing the proof portion
Sourcepub fn proof_to_bytes(&self) -> SolutionByteArray
pub fn proof_to_bytes(&self) -> SolutionByteArray
Clone the proof portion of the solution in its canonical byte string format