pub struct SolverInput {
instance: Instance,
effort: Effort,
equix: EquiXBuilder,
}Expand description
All inputs necessary to run the Solver
Fields
instance: InstanceThe puzzle instance we’re solving
effort: EffortEffort chosen by the client for this solver run
equix: EquiXBuilderConfiguration settings for Equi-X, as an EquiXBuilder instance
Implementations
Sourceimpl SolverInput
impl SolverInput
Sourcepub fn new(instance: Instance, effort: Effort) -> Self
pub fn new(instance: Instance, effort: Effort) -> Self
Construct a SolverInput by wrapping an Instance.
Sourcepub fn runtime(&mut self, option: RuntimeOption) -> &mut Self
pub fn runtime(&mut self, option: RuntimeOption) -> &mut Self
Select the HashX runtime to use for this Solver input.
By default, uses RuntimeOption::TryCompile.
Sourcepub fn solve<R: RngCore + CryptoRng>(self, rng: &mut R) -> Solver
pub fn solve<R: RngCore + CryptoRng>(self, rng: &mut R) -> Solver
Begin solving with this input and a new random Nonce.
Generates a new random Nonce using the provided Rng.
May be parallelized if desired, by cloning the SolverInput first.
Sourcepub fn solve_with_nonce(self, nonce: &Nonce) -> Solver
pub fn solve_with_nonce(self, nonce: &Nonce) -> Solver
Begin solving with a specified Nonce.
This is not generally useful, but it’s great for unit tests if you’d like to skip to a deterministic location in the search.